Writing Documentation — coala 0.11.0.rc1 documentation

# Writing Documentation

This document gives a short introduction on how to write documentation for the coala project.

Documentation is written in reStructuredText and rendered by Read the Docs to our lovely users. You can view the current user documentation on http://docs.coala.io.

To familiarize yourself with the reStructuredText syntax please see this guide.

After getting the coala source code (see Installation Instructions), you can start hacking on existent documentation files. They reside in a separate repository that can be found here.

If you want to add new pages, you need to alter the `index.rst` file in the root of the repository. Please read http://www.sphinx-doc.org/en/stable/markup/toctree.html#toctree-directive for an explanation of the syntax.

You should run this command before trying to build the documentation:

    pip3 install -r docs-requirements.txt

You can test the documentation locally through simply running `make html` in the root directory. This generates `_build\html\index.html` that you can view on your browser.